@@ -2,6 +2,7 @@ from typing import Tuple
 
 import requests
 import whois
+from termcolor import colored
 
 from servergrimoire.plugin import Plugin
 
@@ -16,16 +17,20 @@ class PageChecker(Plugin):
 
     def execute(self, directive: str, data: dict) -> dict:
         w = whois.whois(data["url"])
-        if "http" not in data["url"]:
-            url = f"http://{data['url']}"
-        else:
-            url = data["url"]
+        try:
+            if "https" not in data["url"]:
+                url = f"https://{data['url']}"
+            else:
+                url = data["url"]
+        except requests.exceptions.SSLError:
+            if "http" not in data["url"]:
+                url = f"http://{data['url']}"
         if w["domain_name"] is None:
             output_strng = {"status": 408, "url": url}
         else:
             self.logger.info(w)
             output_strng = {
-                "status": requests.get(url).status_code,
+                "status": requests.head(url, allow_redirects=True).status_code,
                 "url": url,
             }
         self.logger.info(output_strng)
@@ -37,8 +42,21 @@ class PageChecker(Plugin):
             stat[str(data[directive]["status"])] = 1
             other = {}
             if not (200 <= data[directive]["status"] < 400):
+                status = data[directive]["status"]
                 try:
-                    other = {data[directive]["url"]: data[directive]["status"]}
+                    if 300 <= status < 400:
+                        color = "blue"
+                    elif 400 <= status < 500:
+                        color = "yellow"
+                    elif 500 <= status < 600:
+                        color = "red"
+                    else:
+                        color = "cyan"
+                    other = {
+                        colored(data[directive]["url"], color): colored(
+                            data[directive]["status"], color
+                        )
+                    }
                 except KeyError:
                     other = {}
             return stat, other
